==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SectionHeaderCellInfoDescription } from "./SectionHeaderCellInfoDescription";
/**
 * @hidden
 */
var SectionHeaderCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SectionHeaderCellInfoDescriptionMetadata, _super);
    function SectionHeaderCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SectionHeaderCellInfoDescriptionMetadata.b = function (a) {
        if (SectionHeaderCellInfoDescriptionMetadata.a == null) {
            SectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SectionHeaderCellInfoDescriptionMetadata.c(SectionHeaderCellInfoDescriptionMetadata.a);
        }
        if (a.g(SectionHeaderCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(SectionHeaderCellInfoDescriptionMetadata.a);
    };
    SectionHeaderCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ResolvedText", "String");
        a.item("ResolvedSummaryText", "String");
        a.item("SummaryDisplayMode", "ExportedType:string:GroupSummaryDisplayMode");
        a.item("SummaryDisplayMode@names", "List;Cells;RowTop;RowBottom;None");
    };
    SectionHeaderCellInfoDescriptionMetadata.d = function (a) {
        SectionHeaderCellInfoDescriptionMetadata.b(a);
        a.u("SectionHeaderCellInfo", function () { return new SectionHeaderCellInfoDescription(); });
        a.t("SectionHeaderCellInfo", SectionHeaderCellInfoDescriptionMetadata.a);
    };
    SectionHeaderCellInfoDescriptionMetadata.$t = markType(SectionHeaderCellInfoDescriptionMetadata, 'SectionHeaderCellInfoDescriptionMetadata');
    SectionHeaderCellInfoDescriptionMetadata.a = null;
    return SectionHeaderCellInfoDescriptionMetadata;
}(Base));
export { SectionHeaderCellInfoDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SectionHeaderCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SectionHeaderCellInfoDescription } from "./SectionHeaderCellInfoDescription";
/**
 * @hidden
 */
var SectionHeaderCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SectionHeaderCellInfoDescriptionMetadata, _super);
    function SectionHeaderCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SectionHeaderCellInfoDescriptionMetadata.b = function (a) {
        if (SectionHeaderCellInfoDescriptionMetadata.a == null) {
            SectionHeaderCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SectionHeaderCellInfoDescriptionMetadata.c(SectionHeaderCellInfoDescriptionMetadata.a);
        }
        if (a.j(SectionHeaderCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(SectionHeaderCellInfoDescriptionMetadata.a);
    };
    SectionHeaderCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ResolvedText", "String");
        a.item("ResolvedSummaryText", "String");
        a.item("SummaryDisplayMode", "ExportedType:string:GroupSummaryDisplayMode");
        a.item("SummaryDisplayMode@names", "List;Cells;RowTop;RowBottom;None");
    };
    SectionHeaderCellInfoDescriptionMetadata.d = function (a) {
        SectionHeaderCellInfoDescriptionMetadata.b(a);
        a.aa("SectionHeaderCellInfo", function () { return new SectionHeaderCellInfoDescription(); });
        a.z("SectionHeaderCellInfo", SectionHeaderCellInfoDescriptionMetadata.a);
    };
    SectionHeaderCellInfoDescriptionMetadata.$t = markType(SectionHeaderCellInfoDescriptionMetadata, 'SectionHeaderCellInfoDescriptionMetadata');
    SectionHeaderCellInfoDescriptionMetadata.a = null;
    return SectionHeaderCellInfoDescriptionMetadata;
}(Base));
export { SectionHeaderCellInfoDescriptionMetadata };
